Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2077)

Unified Diff: vpython/api/vpython/pep425.proto

Issue 2927573002: [vpython] Fix PEP425 naming. (Closed)
Patch Set: Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: vpython/api/vpython/pep425.proto
diff --git a/vpython/api/vpython/pep425.proto b/vpython/api/vpython/pep425.proto
index 803b4565e45522ac3c4f4d9349fa017fb6c04477..2ef969efd7622be83febf93d3512e0993abf149d 100644
--- a/vpython/api/vpython/pep425.proto
+++ b/vpython/api/vpython/pep425.proto
@@ -7,12 +7,12 @@ syntax = "proto3";
package vpython;
// Represnets a Python PEP425 tag.
qyearsley 2017/06/06 14:33:32 Unrelated typo on this line.
dnj 2017/06/06 19:34:49 Done.
-message Pep425Tag {
- // Version is the PEP425 version tag (e.g., "cp27").
- string version = 1;
- // ABI is the PEP425 ABI tag (e.g., "cp27mu", "none").
+message PEP425Tag {
+ // Version is the PEP425 python tag (e.g., "cp27").
qyearsley 2017/06/06 14:33:32 This comment should be updated too.
dnj 2017/06/06 19:34:50 Done.
+ string python = 1;
+ // ABI is the PEP425 "python ABI" tag (e.g., "cp27mu", "none").
string abi = 2;
- // Arch is the PEP425 architecture tag (e.g., "linux_x86_64", "armv7l",
- // "any").
- string arch = 3;
+ // Platform is the PEP425 "python platform" tag (e.g., "linux_x86_64",
+ // "armv7l", "any").
+ string platform = 3;
}

Powered by Google App Engine
This is Rietveld 408576698